@@ -1,5 +1,5 @@
-__version__ = "1.3.2"
-__date__ = "Oct 31, 2013"
+__version__ = "1.3.5"
+__date__ = "April 15, 2014"
 
 from subprocess import Popen, PIPE, call
 from threading import Thread
